@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 from admin_enhancer.admin import EnhancedModelAdminMixin
-from cms.admin.placeholderadmin import PlaceholderAdmin, FrontendEditableAdmin
+from cms.admin.placeholderadmin import PlaceholderAdminMixin, FrontendEditableAdminMixin
 from copy import deepcopy
 from django.contrib import admin
 from django.conf import settings
+from django.contrib.auth import get_user_model
 from parler.admin import TranslatableAdmin
 
+from .forms import PostAdminForm
 from .models import Post, BlogCategory
-from .settings import BLOG_USE_PLACEHOLDER
+from .settings import get_setting
 
 
 class BlogCategoryAdmin(EnhancedModelAdminMixin, TranslatableAdmin):
@@ -21,8 +23,9 @@ class BlogCategoryAdmin(EnhancedModelAdminMixin, TranslatableAdmin):
         }
 
 
-class PostAdmin(EnhancedModelAdminMixin, FrontendEditableAdmin,
-                PlaceholderAdmin, TranslatableAdmin):
+class PostAdmin(EnhancedModelAdminMixin, FrontendEditableAdminMixin,
+                PlaceholderAdminMixin, TranslatableAdmin, admin.ModelAdmin):
+    form = PostAdminForm
     list_display = ['title', 'author', 'date_published', 'date_published_end']
     date_hierarchy = 'date_published'
     raw_id_fields = ['author']
@@ -42,15 +45,17 @@ class PostAdmin(EnhancedModelAdminMixin, FrontendEditableAdmin,
             'classes': ('collapse',)
         }),
         ('SEO', {
-            'fields': [('meta_description', 'meta_keywords', 'meta_title')],
+            'fields': [('meta_description', 'meta_title', 'meta_keywords')],
             'classes': ('collapse',)
         }),
     ]
 
     def get_fieldsets(self, request, obj=None):
         fsets = deepcopy(self._fieldsets)
-        if not BLOG_USE_PLACEHOLDER:
+        if not get_setting('USE_PLACEHOLDER'):
             fsets[0][1]['fields'].append('post_text')
+        if get_setting('MULTISITE'):
+            fsets[1][1]['fields'][0].append('sites')
         if request.user.is_superuser:
             fsets[1][1]['fields'][0].append('author')
         return fsets
@@ -59,8 +64,12 @@ class PostAdmin(EnhancedModelAdminMixin, FrontendEditableAdmin,
         return {'slug': ('title',)}
 
     def save_model(self, request, obj, form, change):
-        if not obj.author_id:
-            obj.author = request.user
+        if not obj.author_id and get_setting('AUTHOR_DEFAULT'):
+            if get_setting('AUTHOR_DEFAULT') is True:
+                user = request.user
+            else:
+                user = get_user_model().objects.get(username=get_setting('AUTHOR_DEFAULT'))
+            obj.author = user
         super(PostAdmin, self).save_model(request, obj, form, change)
 
     class Media:
